@@ -92,8 +92,8 @@ from .models.select_expression import SelectExpression
 from .models.source import Source, SourceId, SourceName
 from .models.source_reference import FolderSourceReference
 from .models.table_creation_request import TableCreationRequest, RootTableCreationRequest, ViewTableCreationRequest
-from .models.view_materialisation import *
-from .models.view_materialisation_runs import *
+from .models.view_materialisation import ViewMaterialisationJob, ViewMaterialisationJobId, ViewMaterialisationJobName
+from .models.view_materialisation_runs import ViewMaterialisationRun, ViewMaterialisationRunId
 from . import version
 
 
@@ -211,6 +211,10 @@ class Anaml:
         """Send a POST request to the Anaml server."""
         return requests.post(self._url + part, params=self._ref, json=json, headers=self._headers, **kwargs)
 
+    def _delete(self, part, json, **kwargs):
+        """Send a DELETE request to the Anaml server."""
+        return requests.delete(self._url + part, params=self._ref, json=json, headers=self._headers, **kwargs)
+
     # Commits and Branches
 
     def get_current_commit(self, branch: Union[BranchName, str]) -> Commit:
@@ -389,6 +393,18 @@ class Anaml:
         result = self._json_or_handle_errors(r)
         return Feature.from_json(result)
 
+    def delete_feature_by_id(self, feature_id: Union[FeatureId, int]):
+        """Delete a feature from the Anaml server.
+
+        Args:
+            feature_id: Unique identifier of the feature to retrieve.
+
+        Returns:
+            The requested feature, if it exists.
+        """
+        r = self.delete(f"/feature/{int(feature_id)}")
+        self._json_or_handle_errors(r)
+
     def get_feature_by_name(self, name: Union[FeatureName, str]) -> Feature:
         """Get a feature from the Anaml server.
 
@@ -771,7 +787,7 @@ class Anaml:
             feature_set: Union[FeatureSet, FeatureSetCreationRequest],
             *,
             entity: Optional[EntityId] = None,
-            snapshot_date: Optional[Union[str, datetime.date]] = None
+            snapshot_date: Optional[Union[str, date]] = None
     ) -> pandas.DataFrame:
         """Returns a pandas dataframe of the feature set.
 
@@ -789,7 +805,7 @@ class Anaml:
                 req["snapshotDate"] = snapshot_date
             except ValueError:
                 raise ValueError(f"snapshotDate: {snapshot_date} provided is not of the format 'yyyy-mm-dd'")
-        elif isinstance(snapshot_date, datetime):
+        elif isinstance(snapshot_date, date):
             req["snapshotDate"] = snapshot_date.strftime("%Y-%m-%d")
         else:
             req["snapshotDate"] = None
@@ -982,7 +998,9 @@ class Anaml:
         result = self._json_or_handle_errors(r)
         return [ViewMaterialisationJob.from_json(r) for r in result]
 
-    def get_view_materialisation_by_id(self, view_materialisation_id: Union[ViewMaterialisationJobId, int]) -> ViewMaterialisationJob:
+    def get_view_materialisation_by_id(self,
+                                       view_materialisation_id: Union[ViewMaterialisationJobId, int]) \
+            -> ViewMaterialisationJob:
         """Get a view materialisation from the Anaml server.
 
         Args:
