@@ -210,3 +210,38 @@ class JsonObject(dict):
             JSON data ready to be serialised.
         """
         return self.value
+
+
+class DataType(dict):
+    """Passing through the json object for DataType."""
+
+    @classmethod
+    def json_schema(cls) -> dict:
+        """JSON schema for 'JsonObject'.
+
+        Returns:
+            A Python dictionary describing the JSON schema.
+        """
+        return {
+            "type": "object"
+        }
+
+    @classmethod
+    def from_json(cls, data: dict) -> dict:
+        """Validate and parse JSON data into an instance of JsonObject.
+
+        Args:
+            data (dict): JSON data to validate and parse.
+
+        Returns:
+            Passes the data through.
+        """
+        return data
+
+    def to_json(self) -> dict:
+        """Serialise this instance as JSON.
+
+        Returns:
+            JSON data ready to be serialised.
+        """
+        return self.value
